@@ -34,7 +34,7 @@
  ** 									     ** 
  ** ************************************************************************ **/
 
-static char Id[] = "@(#)$Id: ModuleCmd_Avail.c,v 1.10.18.1 2010/07/27 19:09:05 rkowen Exp $";
+static char Id[] = "@(#)$Id: 251840d8d1143e2ca603d419068bc07b85ae78bc $";
 static void *UseId[] = { &UseId, Id };
 
 /** ************************************************************************ **/
@@ -43,6 +43,9 @@ static void *UseId[] = { &UseId, Id };
 
 #include <time.h>
 #include "modules_def.h"
+#if defined HAVE_STRCOLL && defined HAVE_LOCALE_H && defined HAVE_SETLOCALE
+#  include <locale.h>
+#endif
 
 /** ************************************************************************ **/
 /** 				  LOCAL DATATYPES			     **/
@@ -214,6 +217,13 @@ int ModuleCmd_Avail(	Tcl_Interp	*interp,
 	    goto unwind1;
 #endif
 
+#if defined HAVE_STRCOLL && defined HAVE_SETLOCALE
+    /**
+     ** define the collation order using the locale
+     **/
+    (void) setlocale(LC_COLLATE,"");
+#endif
+
     /**
      **  If we're given a full-path, then we'll just check that directory.
      **  Otherwise, we'll check every directory in MODULESPATH.
@@ -747,7 +757,7 @@ fi_ent	*get_dir(	char	*dir,
      **  Allocate memory for reading in the directory
      **/
 
-    if( NULL == (dirlst_cur = dirlst_head = (fi_ent*) calloc( DIREST,
+    if(!(dirlst_cur = dirlst_head = (fi_ent*) module_malloc( DIREST *
 	sizeof( fi_ent)))) {
 	if( OK != ErrorLogger( ERR_ALLOC, LOC, NULL)) {
 	    if( -1 == closedir( dirptr))
@@ -771,7 +781,7 @@ fi_ent	*get_dir(	char	*dir,
 	 **/
 
         if(dirlst_cur == dirlst_last) {
-            if( NULL == (dirlst_head = (fi_ent*) realloc( (char*) dirlst_head, 
+            if(!(dirlst_head = (fi_ent*) module_realloc( (char*) dirlst_head, 
 		(count<<1) * sizeof( fi_ent)))) 
 		if( OK != ErrorLogger( ERR_ALLOC, LOC, NULL)) 
 		    goto unwind0;
@@ -1912,7 +1922,7 @@ static	void _add_file_list( char *name)
 	    _file_list_ptr =
 		(char **) module_malloc(_file_list_cnt * sizeof(char *));
 	else
-	    _file_list_ptr = (char **) realloc( _file_list_ptr,
+	    _file_list_ptr = (char **) module_realloc( _file_list_ptr,
 		_file_list_cnt * sizeof(char *));
 
     }
@@ -2098,8 +2108,12 @@ static	int fi_ent_cmp(	const void	*fi1,
 {
 
 #ifdef DEF_COLLATE_BY_NUMBER
-  return colcomp( ((fi_ent*)fi1)->fi_name, ((fi_ent*)fi2)->fi_name);
+	return colcomp( ((fi_ent*)fi1)->fi_name, ((fi_ent*)fi2)->fi_name);
 #else
-  return strcmp( ((fi_ent*)fi1)->fi_name, ((fi_ent*)fi2)->fi_name);
+#  ifdef HAVE_STRCOLL
+	return strcoll( ((fi_ent*)fi1)->fi_name, ((fi_ent*)fi2)->fi_name);
+#  else
+	return strcmp( ((fi_ent*)fi1)->fi_name, ((fi_ent*)fi2)->fi_name);
+#  endif
 #endif
 }
