@@ -28,7 +28,7 @@
  ** 									     ** 
  ** ************************************************************************ **/
 
-static char Id[] = "@(#)$Id: ModuleCmd_Load.c,v 1.8.2.1 2010/07/27 19:09:05 rkowen Exp $";
+static char Id[] = "@(#)$Id: a760a2092bc185d98e5784b024d8fb85b469fec1 $";
 static void *UseId[] = { &UseId, Id };
 
 /** ************************************************************************ **/
@@ -126,10 +126,17 @@ int	ModuleCmd_Load(	Tcl_Interp	*interp,
      **  Set up the flags controling the Tcl callback functions
      **/
 
-    if( load)
-        g_flags |= M_LOAD;
-    else
-        g_flags |= M_REMOVE;
+	/* avoid changes when invoked as a subcommand */
+	if (!(g_flags & M_SUBCMD)) {
+	    if( load) {
+		g_flags |= M_LOAD;
+		g_flags &= ~M_REMOVE;
+	    } else {
+		g_flags |= M_REMOVE;
+		g_flags &= ~M_LOAD;
+	    }
+	    g_flags |= M_SUBCMD;
+	}
     
     /**
      **  Handle all module files in the order they are passed to me
@@ -146,7 +153,8 @@ int	ModuleCmd_Load(	Tcl_Interp	*interp,
 	 **  Create a Tcl interpreter and initialize it with the module commands
 	 **/
 
-        tmp_interp = Tcl_CreateInterp();
+        tmp_interp = EM_CreateInterp();
+
 	if( TCL_OK != (return_val = InitializeModuleCommands( tmp_interp)))
 	    return( return_val);	/** -------- EXIT (FAILURE) -------> **/
         filename[0] = '\0';
@@ -265,7 +273,7 @@ int	ModuleCmd_Load(	Tcl_Interp	*interp,
 		break;	/* switch */
 	    }
 	}
-        Tcl_DeleteInterp(tmp_interp);
+        EM_DeleteInterp(tmp_interp);
 
 	/* do not process any further modulefiles if EM_EXIT */
 	if (em_return_val == EM_EXIT) break; /* for */
