@@ -30,7 +30,7 @@
  ** 									     ** 
  ** ************************************************************************ **/
 
-static char Id[] = "@(#)$Id: error.c,v 1.8.2.1 2010/07/27 19:09:05 rkowen Exp $";
+static char Id[] = "@(#)$Id: 9f494464b6c815a95b0566b7d69c09cab7aee19f $";
 static void *UseId[] = { &UseId, Id };
 
 /** ************************************************************************ **/
@@ -623,7 +623,7 @@ int Module_Error(	ErrType		  error_type,
 	 **/
 	while( argc >= listsize) {
 	    listsize += ARGLIST_SIZE;
-	    if( NULL == (argv = (char **) realloc( argv,
+	    if(!(argv = (char **) module_realloc( argv,
 		listsize * sizeof(char *)))) {
 		module = module_name;
 		error_type = ERR_ALLOC;
@@ -1463,7 +1463,7 @@ static	char	*ErrorString(	char		 *ErrMsgs,
 	 **  Add a single character to the error string
 	 **/
 	if( ++len >= strsize - 5) {	/** 5 Bytes for safety		     **/
-	    if( NULL == (error_line = (char *) realloc( error_line,
+	    if(!(error_line = (char *) module_realloc( error_line,
 		strsize += ERR_LINELEN))) {
 		ErrorLogger( ERR_ALLOC, LOC, NULL);
 		return( NULL);
@@ -1540,7 +1540,7 @@ static	void	add_param(	char		**Control,
     if( s == buffer && !last) {
 
 	if( ++(*Length) >= strsize) {
-	    if( NULL == (error_line = (char*) realloc( error_line,
+	    if(!(error_line = (char*) module_realloc( error_line,
 		strsize += ERR_LINELEN))) {
 		ErrorLogger( ERR_ALLOC, LOC, NULL);
 		return;
@@ -1573,7 +1573,7 @@ static	void	add_param(	char		**Control,
 	    len = strlen( argv[ index]);
 
 	    while(( *Length + len + 1) >= strsize - 5) {
-		if( NULL == (error_line = (char*) realloc( error_line,
+		if(!(error_line = (char*) module_realloc( error_line,
 		    strsize += ERR_LINELEN))) {
 		    ErrorLogger( ERR_ALLOC, LOC, NULL);
 		    return;
