@@ -377,6 +377,7 @@ typedef enum	{
 #define      M_HELP	0x0100
 #define      M_WHATIS	0x0200
 #define      M_NONPERSIST	0x0400
+#define      M_SUBCMD	0x8000
 
 /**
  **  markers for switching 
@@ -704,6 +705,8 @@ extern	int	  VersionLookup( char*, char**, char**);
 extern	char	 *ExpandVersions( char*);
 
 /**  init.c  **/
+extern	Tcl_Interp	 *EM_CreateInterp(void);
+extern	void	  EM_DeleteInterp(Tcl_Interp*);
 extern	int	  Initialize_Tcl( Tcl_Interp**, int, char*[], char*[]);
 extern	int	  InitializeModuleCommands( Tcl_Interp*);
 extern	int	  Setup_Environment( Tcl_Interp*);
@@ -738,6 +741,7 @@ extern	char	 *xstrtok(char *, const char *);
 extern	void	  chk4spch( char*);
 extern	void	  cleanse_path( const char*, char*, int);
 extern	void	 *module_malloc(size_t);
+extern	void	 *module_realloc(void *,size_t);
 extern	char	 *xdup(char const *);
 extern	char	 *xgetenv(char const *);
 extern  int       tmpfile_mod( char**, FILE**);
@@ -746,6 +750,9 @@ extern	void	  null_free(void **);
 extern	size_t	  countTclHash(Tcl_HashTable *);
 extern	EM_RetVal	ReturnValue( Tcl_Interp*, int);
 extern	void	  OutputExit();
+extern	char 	 *EMGetEnv(Tcl_Interp *, char const *);
+extern	char 	 *EMSetEnv(Tcl_Interp *, char const *, char const *);
+extern	int	  is_interactive(void);
 
 #ifndef HAVE_STRDUP
 #  undef strdup
