@@ -27,7 +27,7 @@
  **			set_marked_entry				     **
  **			Update_LoadedList				     **
  **			check_magic					     **
- **			cleanse_path					     **
+ **			regex_quote					     **
  **			xstrtok						     **
  **			xstrtok_r					     **
  **			chk4spch					     **
@@ -52,7 +52,7 @@
  ** 									     ** 
  ** ************************************************************************ **/
 
-static char Id[] = "@(#)$Id: utility.c,v 1.19.4.2 2010/09/27 23:25:10 rkowen Exp $";
+static char Id[] = "@(#)$Id: 71346743bc4fa2cec67de59999a645f374273ef4 $";
 static void *UseId[] = { &UseId, Id };
 
 /** ************************************************************************ **/
@@ -219,7 +219,7 @@ int store_hash_value(	Tcl_HashTable* htable,
      **/
 
     if( value)
-        Tcl_SetHashValue( hentry, (char*) strdup((char*) value));
+        Tcl_SetHashValue( hentry, (char*) stringer(NULL,0, (char *)value,NULL));
     else
         Tcl_SetHashValue( hentry, (char*) NULL);
     
@@ -522,7 +522,7 @@ Tcl_HashTable	**Copy_Hash_Tables( void)
 		newHashEntry = Tcl_CreateHashEntry( *n_ptr, key, &new);
 
 		if(val)
-		    Tcl_SetHashValue(newHashEntry, strdup(val));
+		    Tcl_SetHashValue(newHashEntry, stringer(NULL,0, val, NULL));
 		else
 		    Tcl_SetHashValue(newHashEntry, (char *) NULL);
 
@@ -606,7 +606,7 @@ int Unwind_Modulefile_Changes(	Tcl_Interp	 *interp,
 
 		    val = (char*) Tcl_GetHashValue( hashEntry);
 		    if( val)
-			Tcl_SetVar2( interp, "env", key, val, TCL_GLOBAL_ONLY);
+			EMSetEnv( interp, key, val);
 
 		} while( hashEntry = Tcl_NextHashEntry( &searchPtr) );
 
@@ -709,7 +709,7 @@ int Output_Modulefile_Changes(	Tcl_Interp	*interp)
 	if( hashEntry = Tcl_FirstHashEntry( table[i], &searchPtr))
 		do {
 			key = (char*) Tcl_GetHashKey( table[i], hashEntry);
-			list[k++] = strdup(key);
+			list[k++] = stringer(NULL,0, key, NULL);
 		} while( hashEntry = Tcl_NextHashEntry( &searchPtr));
 	/* sort hash */
 	if (hcnt > 1)
@@ -726,9 +726,10 @@ int Output_Modulefile_Changes(	Tcl_Interp	*interp)
 		if( i == 1) {
 			output_unset_variable( (char*) key);
 		} else {
-			if(val=(char *) Tcl_GetVar2(interp,"env",
-			key,TCL_GLOBAL_ONLY))
+			val = EMGetEnv(interp, key);
+			if(val && *val)
 				output_set_variable(interp, (char*) key, val);
+			null_free((void *)&val);
 		}
 	} /** for **/
 	/* delloc list */
@@ -966,6 +967,8 @@ static	int Output_Directory_Change(Tcl_Interp *interp)
 		fprintf(stdout, "chdir '%s'%s", change_dir, shell_cmd_separator);
 	} else if( !strcmp( shell_derelict, "python")) {
 		fprintf(stdout, "os.chdir('%s')\n", change_dir);
+	} else if( !strcmp( shell_derelict, "ruby")) {
+		fprintf(stdout, "Dir.chdir('%s')\n", change_dir);
 	} else {
 		rc = TCL_ERROR;
 	}
@@ -1036,7 +1039,7 @@ static	int	output_set_variable(	Tcl_Interp	*interp,
 	 **/
 	if( !strcmp( var, "_LMFILES_")) {
 	    char formatted[ MOD_BUFSIZE];
-	    char *cptr;
+	    char *cptr = NULL;
 	    int	lmfiles_len;
 	    int	count = 0;
 	    char* escaped = stringer(NULL,strlen(val)*2+1,NULL);
@@ -1055,7 +1058,7 @@ static	int	output_set_variable(	Tcl_Interp	*interp,
 			     LMSPLIT_SIZE);
 		buffer[ LMSPLIT_SIZE] = '\0';
 
-		fprintf( stdout, "setenv %s%03d %s%s", var, count, buffer,
+		fprintf( stdout, "setenv %s%03d %s %s", var, count, buffer,
 		    shell_cmd_separator);
 
 		lmfiles_len -= LMSPLIT_SIZE;
@@ -1063,7 +1066,7 @@ static	int	output_set_variable(	Tcl_Interp	*interp,
 	    }
 
 		if( lmfiles_len) {
-		fprintf( stdout, "setenv %s%03d %s%s", var, count,
+		fprintf( stdout, "setenv %s%03d %s %s", var, count,
 		    (escaped + count*LMSPLIT_SIZE), shell_cmd_separator);
 		    count++;
 		}
@@ -1072,33 +1075,37 @@ static	int	output_set_variable(	Tcl_Interp	*interp,
 		 ** Unset _LMFILES_ as indicator to use the multi-variable
 		 ** _LMFILES_
 	     **/
-	    fprintf(stdout, "unsetenv %s%s", var, shell_cmd_separator);
+	    fprintf(stdout, "unsetenv %s %s", var, shell_cmd_separator);
 
 	    } else {	/** if ( lmfiles_len = strlen(val)) > LMSPLIT_SIZE) **/
 
-		fprintf(stdout, "setenv %s %s%s", var, escaped, shell_cmd_separator);
+		fprintf(stdout, "setenv %s %s %s", var, escaped, shell_cmd_separator);
 	    }
 
 	    /**
 	     ** Unset the extra _LMFILES_%03d variables that may be set
 	     **/
 	    do {
+		if (cptr) null_free((void *) &cptr);
 		sprintf( formatted, "_LMFILES_%03d", count++);
-		cptr = (char *) Tcl_GetVar2( interp, "env", formatted, TCL_GLOBAL_ONLY);
-		if( cptr) {
-		    fprintf(stdout, "unsetenv %s%s", formatted, shell_cmd_separator);
+		cptr = EMGetEnv( interp, formatted);
+		if(cptr && *cptr) {
+		    fprintf(stdout, "unsetenv %s %s", formatted,
+			shell_cmd_separator);
 		}
-	    } while( cptr);
-	
-	  null_free((void *) &escaped);
+	    } while( cptr && *cptr);
+
+	    null_free((void *) &cptr);
+	    null_free((void *) &escaped);
 
 	} else {	/** if( var == "_LMFILES_") **/
 
 #endif /* not LMSPLIT_SIZE */
-	  
+
 		char* escaped = stringer(NULL,strlen(val)*2+1,NULL);
 		EscapeCshString(val,escaped);
-		fprintf(stdout, "setenv %s %s %s", var, escaped, shell_cmd_separator);
+		fprintf(stdout, "setenv %s %s %s", var, escaped,
+			shell_cmd_separator);
 		null_free((void *) &escaped);
 #ifdef LMSPLIT_SIZE
 	}
@@ -1132,6 +1139,18 @@ static	int	output_set_variable(	Tcl_Interp	*interp,
 			shell_cmd_separator);  
 		null_free((void *) &escaped);
 
+    /**
+     **  PYTHON
+     **/
+    } else if( !strcmp((char*) shell_derelict, "python")) {
+	fprintf( stdout, "os.environ['%s'] = '%s'\n", var, val);
+
+    /**
+     **  RUBY
+     **/
+    } else if( !strcmp((char*) shell_derelict, "ruby")) {
+	fprintf( stdout, "ENV['%s'] = '%s'\n", var, val);
+
     /**
      **  CMAKE
      **/
@@ -1142,12 +1161,6 @@ static	int	output_set_variable(	Tcl_Interp	*interp,
 			shell_cmd_separator);
 		null_free((void *) &escaped);
 
-    /**
-     **  PYTHON
-     **/
-    } else if( !strcmp((char*) shell_derelict, "python")) {
-	fprintf( stdout, "os.environ['%s'] = '%s'\n", var, val);
-
     /**
      ** SCM
      **/
@@ -1222,6 +1235,8 @@ static	int	output_unset_variable( const char* var)
 	fprintf( stdout, "unset(ENV{%s})%s", var, shell_cmd_separator);  
     } else if( !strcmp( shell_derelict, "python")) {
       fprintf( stdout, "os.environ['%s'] = ''\ndel os.environ['%s']\n",var,var);
+    } else if( !strcmp( shell_derelict, "ruby")) {
+      fprintf( stdout, "ENV['%s'] = nil\n",var);
     } else if( !strcmp( shell_derelict, "scm")) {
 	fprintf( stdout, "(putenv \"%s\")\n", var);
     } else if( !strcmp( shell_derelict, "mel")) {
@@ -1407,7 +1422,7 @@ static	int	output_set_alias(	const char	*alias,
 	 **  Shells supporting extended bourne shell syntax ....
 	 **/
 	if( (!strcmp( shell_name, "sh") && bourne_alias)
-		||  !strcmp( shell_name, "bash")
+		||  (!strcmp( shell_name, "bash") && is_interactive())
                 ||  !strcmp( shell_name, "zsh" )
                 ||  !strcmp( shell_name, "ksh")) {
 	    /**
@@ -1456,8 +1471,8 @@ static	int	output_set_alias(	const char	*alias,
 
 	    fprintf( aliasfile, "'%c", alias_separator);
 
-        } else if( !strcmp( shell_name, "sh")
-		&&   bourne_funcs) {
+        } else if( ((!strcmp( shell_name, "sh")) && bourne_funcs)
+        || (!strcmp( shell_name, "bash") && !is_interactive())) {
 	/**
 	 **  The bourne shell itself
          **  need to write a function unless this sh doesn't support
@@ -1638,13 +1653,13 @@ char	*getLMFILES( Tcl_Interp	*interp)
     if( lmfiles)
         null_free((void *) &lmfiles);
 
-    lmfiles = (char *) Tcl_GetVar2( interp, "env","_LMFILES_",TCL_GLOBAL_ONLY);
+    lmfiles = EMGetEnv( interp, "_LMFILES_");
 
     /**
      **  Now the pointer is NULL in case of the variable has not been defined.
      **  In this case try to read in the splitted variable from _LMFILES_xxx
      **/
-    if( !lmfiles) {
+    if( !lmfiles || !*lmfiles) {
 
         char	buffer[ MOD_BUFSIZE];	/** Used to set up the split variab- **/
 					/** les name			     **/
@@ -1659,9 +1674,9 @@ char	*getLMFILES( Tcl_Interp	*interp)
 	 **  in
 	 **/
         sprintf( buffer, "_LMFILES_%03d", count++);
-        cptr = (char *) Tcl_GetVar2( interp, "env", buffer, TCL_GLOBAL_ONLY);
+        cptr = EMGetEnv( interp, buffer);
 
-        while( cptr) {			/** Something available		     **/
+	while(cptr && *cptr) {		/** Something available		     **/
 
 	    /**
 	     **  Count up the variables length
@@ -1674,8 +1689,8 @@ char	*getLMFILES( Tcl_Interp	*interp)
 	     **  Reallocate the value's buffer and copy the current split
 	     **  part at its end
 	     **/
-            if((char *) NULL == (lmfiles =
-		(char*) realloc( lmfiles, lmsize * sizeof(char) + 1))) {
+            if(!(lmfiles =
+		(char*) module_realloc( lmfiles, lmsize * sizeof(char) + 1))) {
 		    if( OK != ErrorLogger( ERR_ALLOC, LOC, NULL))
 			return( NULL);		/** ---- EXIT (FAILURE) ---> **/
 	    }
@@ -1687,7 +1702,7 @@ char	*getLMFILES( Tcl_Interp	*interp)
 	     **  Read the next split part variable
 	     **/
             sprintf( buffer, "_LMFILES_%03d", count++);
-            cptr = (char *) Tcl_GetVar2( interp,"env",buffer, TCL_GLOBAL_ONLY);
+            cptr = EMGetEnv( interp,buffer);
         }
 
     } else {  /** if( lmfiles) **/
@@ -1697,7 +1712,7 @@ char	*getLMFILES( Tcl_Interp	*interp)
 	 **  of the returned buffer into a free allocated one in order to
 	 **  avoid side effects.
 	 **/
-	char	*tmp = strdup(lmfiles);
+	char	*tmp = stringer(NULL,0, lmfiles, NULL);
 
 	if( !tmp)
 	    if( OK != ErrorLogger( ERR_ALLOC, LOC, NULL))
@@ -1723,7 +1738,7 @@ char	*getLMFILES( Tcl_Interp	*interp)
  ** 									     **
  **   Function:		IsLoaded					     **
  ** 									     **
- **   Description:	Check wether the passed modulefile is currently      **
+ **   Description:	Check whether the passed modulefile is currently     **
  **			loaded						     **
  ** 									     **
  **   First Edition:	1991/10/23					     **
@@ -1806,8 +1821,7 @@ static int __IsLoaded(	Tcl_Interp	 *interp,
      **  Get a list of loaded modules (environment variable 'LOADEDMODULES')
      **  and the list of loaded module-files (env. var. __LMFILES__)
      **/
-    char	*loaded_modules = (char *) Tcl_GetVar2( interp, "env",
-			"LOADEDMODULES", TCL_GLOBAL_ONLY);
+    char	*loaded_modules = EMGetEnv( interp, "LOADEDMODULES");
     char	*loaded_modulefiles = getLMFILES( interp);
     
 #if WITH_DEBUGGING_UTIL_2
@@ -1818,8 +1832,9 @@ static int __IsLoaded(	Tcl_Interp	 *interp,
      **  If no module is currently loaded ... the requested module is surely
      **  not loaded, too ;-)
      **/
-    if( !loaded_modules) 
+    if( !loaded_modules || !*loaded_modules) {
 	goto unwind0;
+    }
     
     /**
      **  Copy the list of currently loaded modules into a new allocated array
@@ -1972,6 +1987,7 @@ unwind2:
 unwind1:
     null_free((void *) &l_modules);
 unwind0:
+    null_free((void *)&loaded_modules);
     return( 0);				/** -------- EXIT (FAILURE) -------> **/
 
 success0:
@@ -2159,7 +2175,7 @@ int Update_LoadedList(	Tcl_Interp	*interp,
      **  the path too.
      **/
     if( g_flags & M_REMOVE) {
-	module = strdup( modulename);
+	module = stringer(NULL,0, modulename, NULL);
 	basename = module;
 	if( basename = get_module_basename( basename)) {
 	argv[2] = basename;
@@ -2248,7 +2264,7 @@ int check_magic( char	*filename,
 /*++++
  ** ** Function-Header ***************************************************** **
  ** 									     **
- **   Function:		cleanse_path					     **
+ **   Function:		regex_quote					     **
  ** 									     **
  **   Description:	Copy the passed path into the new path buffer and    **
  **			devalue '.' and '+'				     **
@@ -2268,7 +2284,7 @@ int check_magic( char	*filename,
  ** ************************************************************************ **
  ++++*/
 
-void cleanse_path( const char	*path,
+void regex_quote( const char	*path,
 		         char	*newpath,
 			 int	 len)
 {
@@ -2507,8 +2523,9 @@ void chk4spch(char* s)
  ** ** Function-Header ***************************************************** **
  ** 									     **
  **   Function:		module_malloc					     **
+ **   			module_realloc					     **
  ** 									     **
- **   Description:	A wrapper for the system malloc() function,	     **
+ **   Description:	A wrapper for the system malloc(),realloc() function **
  ** 			so the argument can be tested and set to a positive  **
  ** 			value.						     **
  ** 									     **
@@ -2523,11 +2540,31 @@ void chk4spch(char* s)
 
 
 void *module_malloc(size_t size) {
+	void *ret;
 
-	return malloc(size > 0 ? size : 1);
+	if (size == 0)	size = 1;
+#ifdef TCL_MEM_DEBUG
+	ret = ckalloc(size);
+#else
+	ret = malloc(size);
+#endif
+	ret = memset(ret,'\0',size);
 
+	return ret;
 } /** End of 'module_malloc' **/
 
+void *module_realloc(void * ptr, size_t size) {
+	void *ret;
+
+#ifdef TCL_MEM_DEBUG
+	ret = ckrealloc(ptr, size);
+#else
+	ret = realloc(ptr, size);
+#endif
+
+	return ret;
+} /** End of 'module_realloc' **/
+
 /*++++
  ** ** Function-Header ***************************************************** **
  ** 									     **
@@ -2644,7 +2681,7 @@ char *xdup(char const *string) {
 			}
 		}
 		null_free((void *) &result);
-		return strdup(buffer);
+		return stringer(NULL,0, buffer, NULL);
 	}
 
 } /** End of 'xdup' **/
@@ -2947,7 +2984,11 @@ void null_free(void ** var) {
 	if (! *var) return;	/* passed in a NULL ptr */
 
 #ifdef USE_FREE
+#  ifdef TCL_MEM_DEBUG
+	ckfree( *var);
+#  else
 	free( *var);
+#  endif
 #endif
 	*var = NULL;
 
@@ -3013,23 +3054,38 @@ EM_RetVal ReturnValue(Tcl_Interp *interp, int retval) {
 			*endp		= (char *) NULL;
 	const char 	*tstr;
 	int		 result;
-	static Tcl_RegExp	exit__expPtr,
-				break_expPtr,
-				continue_expPtr;
+	static char	*Exit_	= "^EXIT ([0-9]*)",
+			*Break	= ".*\"break\".*",
+			*Cont	= ".*\"continue\".*";
+	static Tcl_Obj	*exit_Ptr	= (Tcl_Obj *) NULL,
+			*break_Ptr	= (Tcl_Obj *) NULL,
+			*cont_Ptr	= (Tcl_Obj *) NULL;
+	static Tcl_RegExp	exit__expPtr	= (Tcl_RegExp) NULL,
+				break_expPtr	= (Tcl_RegExp) NULL,
+				cont_expPtr	= (Tcl_RegExp) NULL;
 
 	tstr = (const char *) TCL_RESULT(interp);
 
 	/* compile regular expression the first time through */
+	if (!exit_Ptr)
+		exit_Ptr	= Tcl_NewStringObj(Exit_,strlen(Exit_));
 	if (!exit__expPtr)
-		exit__expPtr = Tcl_RegExpCompile(interp, "^EXIT ([0-9]*)");
+		exit__expPtr = Tcl_GetRegExpFromObj(interp,
+			exit_Ptr,TCL_REG_ADVANCED);
 
 	/*  result = "invoked \"break\" outside of a loop" */
+	if (!break_Ptr)
+		break_Ptr	= Tcl_NewStringObj(Break,strlen(Break));
 	if (!break_expPtr)
-		break_expPtr = Tcl_RegExpCompile(interp, ".*\"break\".*");
+		break_expPtr = Tcl_GetRegExpFromObj(interp,
+			break_Ptr,TCL_REG_ADVANCED);
 
 	/*  result = "invoked \"continue\" outside of a loop" */
-	if (!continue_expPtr)
-		continue_expPtr = Tcl_RegExpCompile(interp, ".*\"continue\".*");
+	if (!cont_Ptr)
+		cont_Ptr	= Tcl_NewStringObj(Cont,strlen(Cont));
+	if (!cont_expPtr)
+		cont_expPtr = Tcl_GetRegExpFromObj(interp,
+			cont_Ptr,TCL_REG_ADVANCED);
 
 	/* intercept any "EXIT N" first */
 	if(tstr && *tstr && 0 < Tcl_RegExpExec(interp, exit__expPtr,
@@ -3049,7 +3105,7 @@ EM_RetVal ReturnValue(Tcl_Interp *interp, int retval) {
 		em_result = EM_BREAK;
 
 	/* check for a continue not within loop */
-	} else if(tstr && *tstr && 0 < Tcl_RegExpExec(interp, continue_expPtr,
+	} else if(tstr && *tstr && 0 < Tcl_RegExpExec(interp, cont_expPtr,
 		(CONST84 char *) tstr, (CONST84 char *) tstr)){
 		em_result = EM_CONTINUE;
 
@@ -3107,3 +3163,109 @@ void OutputExit() {
 		fprintf( stdout, " test 0 = 1;");
 	}
 } /** End of 'OutputExit' **/
+
+/*++++
+ ** ** Function-Header ***************************************************** **
+ ** 									     **
+ **   Function:		EMGetEnv					     **
+ ** 									     **
+ **   Description:	Wrap the Tcl_GetVar2() call and return an allocated  **
+ ** 			string						     **
+ ** 									     **
+ **   first edition:	2011/08/15	R.K.Owen <rk@owen.sj.ca.us>	     **
+ ** 									     **
+ **   Parameters:	Tcl_Interp	 *interp	 TCL interp.	     **
+ **   			char	*var		Environment variable	     **
+ ** 									     **
+ **   Result:		char    *		An allocated string	     **
+ ** 									     **
+ ** ************************************************************************ **
+ ++++*/
+char * EMGetEnv(	Tcl_Interp	 *interp, 
+			char const	 *var) {
+
+	char *value, *string;
+
+	Tcl_Preserve(interp);
+	value = (char *) Tcl_GetVar2( interp, "env", var, TCL_GLOBAL_ONLY);
+	Tcl_Release(interp);
+	string = stringer(NULL, 0, value, NULL);
+
+	if(!string)
+		if (OK != ErrorLogger(ERR_ALLOC, LOC, NULL))
+			return (NULL);		/** ---- EXIT (FAILURE) ---> **/
+
+	return string;
+
+} /** End of 'EMGetEnv' **/
+
+/*++++
+ ** ** Function-Header ***************************************************** **
+ ** 									     **
+ **   Function:		EMSetEnv					     **
+ ** 									     **
+ **   Description:	Wrap the Tcl_SetVar2() call and return an allocated  **
+ ** 			string						     **
+ ** 									     **
+ **   first edition:	2011/09/26	R.K.Owen <rk@owen.sj.ca.us>	     **
+ ** 									     **
+ **   Parameters:	Tcl_Interp	 *interp	 TCL interp.	     **
+ **   			char	*var		Environment variable	     **
+ **   			char	*val		New value		     **
+ ** 									     **
+ **   Result:		char    *		current value string	     **
+ ** 									     **
+ ** ************************************************************************ **
+ ++++*/
+char * EMSetEnv(	Tcl_Interp	 *interp, 
+			char const	 *var,
+			char const	 *val) {
+
+	char *value;
+
+	Tcl_Preserve(interp);
+	value = (char *) Tcl_SetVar2( interp, "env", var, val, TCL_GLOBAL_ONLY);
+	Tcl_Release(interp);
+
+	return value;
+
+} /** End of 'EMSetEnv' **/
+
+/*++++
+ ** ** Function-Header ***************************************************** **
+ ** 									     **
+ **   Function:		is_interactive					     **
+ ** 									     **
+ **   Description:	Test whether an interactive shell or not	     **
+ ** 			(for bash)					     **
+ ** 									     **
+ **   first edition:	2012/05/21	R.K.Owen <rk@owen.sj.ca.us>	     **
+ ** 									     **
+ **   Parameters:	none						     **
+ ** 									     **
+ **   Result:		int    			return 1 if true, else 0     **
+ ** 									     **
+ ** ************************************************************************ **
+ ++++*/
+int is_interactive(void) {
+
+	static int saved = -1;
+	FILE *tty = (FILE *) NULL;
+
+	if (saved < 0) {
+		/* try /dev/tty */
+		if (!(tty = fopen("/dev/tty","w"))) {
+			saved = 0;	/* no tty - hence non-interactive */
+		} else if (isatty(fileno(stdin)) || isatty(fileno(stdout))
+		|| isatty(fileno(stderr))) {
+			/* at least one of stdin/out/err is a tty */
+			saved = 1;
+		} else {
+			saved = 0;
+		}
+		if (tty)	fclose(tty);
+	}
+
+	return saved;
+
+} /** End of 'is_interactive' **/
